@@ -16,17 +16,14 @@ use POE::Component::IRC::Plugin qw(:ALL);
 use base qw(POE::Component::IRC);
 use vars qw($VERSION);
 
-$VERSION = '2.40';
+$VERSION = '2.0';
 
 # Event handlers for tracking the STATE. $self->{STATE} is used as our namespace.
 # u_irc() is used to create unique keys.
 
 # Make sure we have a clean STATE when we first join the network and if we inadvertently get disconnected
 sub S_001 {
-  my $self = shift;
-  delete $self->{STATE};
-  $self->{STATE}->{usermode} = '';
-  $self->yield( 'mode', $self->{RealNick} );
+  delete $_[0]->{STATE};
   return PCI_EAT_NONE;
 }
 
@@ -120,20 +117,9 @@ sub S_quit {
   my ($self,$irc) = splice @_, 0, 2;
   my $mapping = $irc->isupport('CASEMAPPING');
   my $nick = ( split /!/, ${ $_[0] } )[0];
-  my $msg = ${ $_[1] };
   push @{ $_[2] }, [ $self->nick_channels( $nick ) ];
   my $unick = u_irc $nick, $mapping;
 
-  # Check if it is a netsplit
-  if ( $msg ) {
-    SWITCH: {
-       my @args = split /\s/, $msg;
-       if ( @args != 2 ) {
-	 last SWITCH;
-       }
-    }
-  }
-
   if ( $unick eq u_irc ( $self->nick_name(), $mapping ) ) {
         delete $self->{STATE};
   } else {
@@ -151,7 +137,6 @@ sub S_kick {
   my $mapping = $irc->isupport('CASEMAPPING');
   my $channel = ${ $_[1] };
   my $nick = ${ $_[2] };
-  push @{ $_[$#_] }, $self->nick_long_form( $nick );
   my $unick = u_irc $nick, $mapping;
   my $uchan = u_irc $channel, $mapping;
 
@@ -211,7 +196,7 @@ sub S_chan_mode {
   pop @_;
   my $mode = ${ $_[2] };
   my $arg = ${ $_[3] };
-  return PCI_EAT_NONE unless $mode =~ /\+[qoah]/ and $mynick eq u_irc( $arg, $mapping );
+  return PCI_EAT_NONE unless $mynick = u_irc( $arg, $mapping ) and $mode =~ /\+[qoah]/;
   my $excepts = $irc->isupport('EXCEPTS');
   my $invex = $irc->isupport('INVEX');
   $irc->yield ( 'mode' => $channel => $excepts ) if $excepts;
@@ -219,14 +204,6 @@ sub S_chan_mode {
   return PCI_EAT_NONE;
 }
 
-sub S_221 {
-  my ($self,$irc) = splice @_, 0, 2;
-  my $mode = ${ $_[0] };
-  $mode =~ s/^\+//;
-  ($self->{STATE}->{usermode} = $mode ) =~ s/^\+//;
-  return PCI_EAT_NONE;
-}
-
 # Channel MODE
 sub S_mode {
   my ($self,$irc) = splice @_, 0, 2;
@@ -246,7 +223,7 @@ sub S_mode {
 
   # Do nothing if it is UMODE
   if ( $uchan ne u_irc ( $self->{RealNick}, $mapping ) ) {
-     my $parsed_mode = parse_mode_line( $prefix, $chanmodes, @modes );
+     my $parsed_mode = parse_mode_line( @modes );
      while ( my $mode = shift ( @{ $parsed_mode->{modes} } ) ) {
         my $arg;
         $arg = shift ( @{ $parsed_mode->{args} } ) if ( $mode =~ /^(.[$alwaysarg]|\+[$chanmodes->[2]])/ );
@@ -319,21 +296,6 @@ sub S_mode {
         delete $self->{STATE}->{Chans}->{ $uchan }->{Mode};
      }
   }
-  else {
-     my $parsed_mode = parse_mode_line( @modes );
-     while ( my $mode = shift ( @{ $parsed_mode->{modes} } ) ) {
-	if ( $mode =~ /^\+(.)/ ) {
-		my $flag = $1;
-		$self->{STATE}->{usermode} .= $flag unless $self->{STATE}->{usermode} =~ /$flag/;
-		next;
-	}
-        if ( $mode =~ /^-(.)/ ) {
-                my $flag = $1;
-		$self->{STATE}->{usermode} =~ s/$flag// if $self->{STATE}->{usermode} =~ /$flag/;
-		next;
-	}
-     }
-  }
   return PCI_EAT_NONE;
 }
 
@@ -553,11 +515,6 @@ sub S_333 {
 # Internal methods begin with '_'
 #
 
-sub umode {
-  my $self = shift;
-  return $self->{STATE}->{usermode};
-}
-
 sub _channel_sync {
   my $self = shift;
   my $mapping = $self->isupport('CASEMAPPING');
@@ -577,31 +534,26 @@ sub _channel_sync {
 
 sub _nick_exists {
   my $self = shift;
-  my $nick = shift || return;
   my $mapping = $self->isupport('CASEMAPPING');
-  $nick = u_irc $nick, $mapping;
+  my $nick = u_irc $_[0], $mapping || return 0;
   return 1 if defined $self->{STATE}->{Nicks}->{ $nick };
   return 0;
 }
 
 sub _channel_exists {
   my $self = shift;
-  my $channel = shift || return;
   my $mapping = $self->isupport('CASEMAPPING');
-  $channel = u_irc $channel, $mapping;
+  my $channel = u_irc $_[0], $mapping || return 0;
   return 1 if defined $self->{STATE}->{Chans}->{ $channel };
   return 0;
 }
 
 sub _nick_has_channel_mode {
   my $self = shift;
-  my $channel = shift || return;
-  my $nick = shift || return;
-  my $flag = shift || return;
   my $mapping = $self->isupport('CASEMAPPING');
-  $channel = u_irc $channel, $mapping;
-  $nick = u_irc $nick, $mapping;
-  $flag = ( split //, $flag )[0];
+  my $channel = u_irc $_[0], $mapping || return 0;
+  my $nick = u_irc $_[1], $mapping || return 0;
+  my $flag = ( split //, $_[2] )[0] || return 0;
 
   return 0 unless $self->is_channel_member($channel,$nick);
   return 1 if $self->{STATE}->{Nicks}->{ $nick }->{CHANS}->{ $channel } =~ /$flag/;
@@ -636,9 +588,13 @@ sub nick_info {
   return unless $self->_nick_exists($nick);
 
   my $record = $self->{STATE}->{Nicks}->{ $nick };
+
   my %result = %{ $record };
+
   $result{Userhost} = $result{User} . '@' . $result{Host};
+
   delete $result{'CHANS'};
+
   return \%result;
 }
 
@@ -1000,10 +956,6 @@ All of the L<POE::Component::IRC> methods are supported, plus the following:
 
 =over
 
-=item umode
-
-Takes no parameters. Returns the current user mode set for the bot.
-
 =item channels
 
 Takes no parameters. Returns a hashref, keyed on channel name and whether the bot is operator, halfop or 
@@ -1169,17 +1121,13 @@ ARG2 contains an arrayref of channel names that are common to the quitting clien
 
 ARG2 contains an arrayref of channel names that are common to the nick changing client and the component.
 
-=item irc_kick
-
-Additional parameter ARG4 contains the full nick!user@host of the kicked individual.
-
 =back
 
 =head1 CAVEATS
 
 The component gathers information by registering for 'irc_quit', 'irc_nick', 'irc_join', 'irc_part', 'irc_mode', 'irc_kick' and
 various numeric replies. When the component is asked to join a channel, when it joins it will issue a 'WHO #channel' and a 'MODE #channel'. These will solicit between them the numerics, 'irc_352' and 'irc_324'.
-You may want to ignore these. When someone joins a channel the bot is on, it issues a 'WHO nick'.
+You may want to ignore these. When someones joins a channel the bot is on, it issues a 'WHO nick'.
 
 Currently, whenever the component sees a topic or channel list change, it will use time() for the SetAt value and the full address of the user who set it for the SetBy value. When an ircd gives us it's record 
 of such changes, it will use it's own time (obviously) and may only give us the nickname of the user, rather than their full address. Thus, if our time() and the ircd's time do not match, or the ircd uses the
